summaryrefslogtreecommitdiff
path: root/Omni/Cloud/post-receive.sh
diff options
context:
space:
mode:
Diffstat (limited to 'Omni/Cloud/post-receive.sh')
-rwxr-xr-xOmni/Cloud/post-receive.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/Omni/Cloud/post-receive.sh b/Omni/Cloud/post-receive.sh
index 179fbd0..8df799f 100755
--- a/Omni/Cloud/post-receive.sh
+++ b/Omni/Cloud/post-receive.sh
@@ -6,11 +6,11 @@
# properly, so we have to manually deploy this like so:
#
# scp Omni/Cloud/post-receive \
-# root@simatime.com:/srv/git/.gitolite/hooks/common/post-receive
+# root@bensima.com:/srv/git/.gitolite/hooks/common/post-receive
#
# One time only:
#
# ssh root@simatime.com "sudo -u git gitolite setup -ho"
#
# Also on first-time setup, might need to manually check the permissions are
# correct on $webroot/archive or wherever else.
@@ -22,13 +22,13 @@ do
then
repo=$(basename "$PWD" | sed 's/.git//g')
branch=$(git rev-parse --symbolic --abbrev-ref "$refname")
- webroot="/srv/www/simatime.com/"
+ webroot="/srv/www/bensima.com/"
outdir="$webroot/archive/$repo/$branch"
mkdir -p "$outdir"
- echo " making: https://simatime.com/archive/$repo/$branch/$newrev.tar.gz"
+ echo " making: https://git.bensima.com/archive/$repo/$branch/$newrev.tar.gz"
git archive "$branch" --prefix "$repo-$branch/" --format tar \
| gzip > "$outdir/$newrev.tar.gz"
- echo " making: https://simatime.com/archive/$repo/$branch/$newrev.sha256"
+ echo " making: https://git.bensima.com/archive/$repo/$branch/$newrev.sha256"
hash=$(nix-prefetch-url --unpack file://"$outdir"/"$newrev".tar.gz 2>/dev/null)
echo "$hash" > "$outdir/$newrev.sha256"
echo " commit: $newrev"
@@ -6,11 +6,11 @@
# One time only:
#
-# ssh root@simatime.com "sudo -u git gitolite setup -ho"
+# ssh root@bensima.com "sudo -u git gitolite setup -ho"
#
# Also on first-time setup, might need to manually check the permissions are